function update_view_based_on_selected_domain() {
  let selected_domain = $('select#domain');
  let uri = `${this.document.baseURI}.js`;
  let params = `domain_id=${selected_domain.val()}`;

  // update the content div, based on the selected domain
  $.ajax({
    url: uri,
    type: 'GET',
    data: params,
    dataType: 'html',
    context: $(this),
  }).done(function (data, textStatus, jqXHR) {
    // All OK
    $("#ugrp_content").html(data);
  }).fail(function (jqXHR, textStatus, errorThrown) {
    // Something went wrong
  }).always(function (jqXHROrData, textStatus, jqXHROrErrorThrown) {
    // Clean up
  });
}

$(function () {
  // Initial view update
  update_view_based_on_selected_domain();

  $(document).on('change', 'select#domain', function (e) {
    update_view_based_on_selected_domain();
  });

  $(document).on('change', '.ugrp_checkbox', function (e) {
    // '/ugrp/acl_change/:acl/:state'
    let checkbox = $(this)[0];
    let acl = checkbox.id;
    let state = checkbox.checked ? 'true' : 'false';
    let uri = `${this.baseURI}/acl_change/${acl}/${state}`;
    let params = null;

    $.ajax({
      url: uri,
      type: 'POST',
      data: params,
      dataType: 'json',
      contentType: 'application/json;charset=UTF-8',
      context: $(this),
    }).done(function (data, textStatus, jqXHR) {
      // All OK

      // Update id tag on checkbox
      let id_original = $(this)[0].id;
      let id_parts = id_original.split('-');
      let lhs = `${id_parts[0].split('_')[0]}_id`;
      let rhs = `${id_parts[0].split('_')[1]}_id`;
      let suffix = '';
      let remainder = id_parts.splice(3);
      if (remainder.length) { suffix = `-${remainder.join('-')}`; }
      let id_new = `${id_parts[0]}-${data[lhs]}-${data[rhs]}${suffix}`;
      $(this)[0].id = id_new;

      // var message = `Done: ${jqXHR.status}: ${jqXHR.statusText}`;
      // $('#notice').text(message).css('color', 'green');

      let chkbox = $(this);
      chkbox.css({ 'outline-color': 'green', 'outline-style': 'solid', 'outline-width': 'medium' });

      // Clean up
      setTimeout(function () { chkbox.css({ 'outline': '0' }); }, 3000);
      setTimeout(function () { $('#notice').text('').css('color', ''); }, 2000);

    }).fail(function (jqXHR, textStatus, errorThrown) {
      // Something went wrong

      let message;
      // if (typeof jqXHR.responseJSON !== 'undefined') {
      //   message = `Failed: ${jqXHR.status}: ${jqXHR.statusText} (${jqXHR.responseJSON[0]})`;
      if (typeof jqXHR.responseText !== 'undefined') {
        message = `Failed: ${jqXHR.status}: ${jqXHR.statusText} (${jqXHR.responseText})`;
      } else {
        message = `Failed: ${jqXHR.status}: ${jqXHR.statusText}`;
      }
      $('#notice').text(message).css('color', 'red');

      let chkbox = $(this);
      chkbox.css({ 'outline-color': 'red', 'outline-style': 'solid', 'outline-width': 'medium' });

      // Clean up
      setTimeout(function () { chkbox.css({ 'outline': '0' }); }, 3000);
      setTimeout(function () { $('#notice').text('').css('color', ''); }, 2000);

    }).always(function (jqXHROrData, textStatus, jqXHROrErrorThrown) {
      // Clean up
    });
  });

});
