# Helper functions for determining the active domain from the requested URI

module Ugrp
  module DomainHelper
    def self.get_domain_from_request(request = nil, controller = nil, cookies = nil)
      request_host = request&.host
      request_host = ActionMailer::Base.default_url_options[:host] if request_host.nil?
      request_host = request_host.slice(0..(request_host.index(':') - 1)) unless request_host.index(':').nil?
      request_host = request_host&.gsub(/^www\./, '')

      Rails.logger.debug {
        "Ugrp::DomainHelper.get_domain_from_request : " \
          "(#{request_host.nil? ? 'unable to determine request hostname' : "request_host = #{request_host}"})"
      }

      current_domain = Ugrp::Domain.get_domain_from_request(request_host)

      Rails.logger.debug {
        "Ugrp::DomainHelper.get_domain_from_request : " \
          "current_domain = #{current_domain&.url}(#{current_domain&.name}) / default locale = #{current_domain&.default_locale}"
      }

      unless Ugrp.alternate_domain_resolver.nil?
        # current_domain = eval("#{Ugrp.alternate_domain_resolver}(request, current_domain, controller, cookies)")

        k = Ugrp.alternate_domain_resolver.split('.')[0].constantize
        m = Ugrp.alternate_domain_resolver.split('.')[1].to_sym

        current_domain = k.send(m, request, current_domain, controller, cookies)

        Rails.logger.debug {
          "Ugrp::DomainHelper.get_domain_from_request (alternate_domain_resolver=#{Ugrp.alternate_domain_resolver}) : " \
            "current_domain = #{current_domain&.url}(#{current_domain&.name}) / default locale = #{current_domain&.default_locale}"
        }
      end

      current_domain
    end
  end
end
